@@ -11,11 +11,7 @@ import pprint
 import copy
 import json
 
-from ruamel.yaml.comments import CommentedMap
-from urllib.request import urlopen
-
 import jsonschema
-import pkgutil
 
 schema_base_url = "http://devicetree.org/"
 schema_basedir = os.path.dirname(os.path.abspath(__file__))
@@ -24,35 +20,41 @@ schema_basedir = os.path.dirname(os.path.abspath(__file__))
 # peformance impact.
 re._MAXCACHE = 2048
 
+
 class tagged_list(list):
 
     tags = {u'!u8': 8, u'!u16': 16, u'!u32': 32, u'!u64': 64}
 
     def __init__(self, int_list, tag, tags=tags):
+        int_list = [sized_int(i, size=tags[tag]) for i in int_list]
         super().__init__(int_list)
-        self.type_size = tags[tag]
 
     @staticmethod
     def constructor(loader, node):
         return tagged_list(loader.construct_sequence(node), node.tag)
 
-class phandle_int(int):
 
-    def __new__(cls, value):
+class sized_int(int):
+    def __new__(cls, value, *args, **kwargs):
         return int.__new__(cls, value)
 
+    def __init__(self, value, size=32, phandle=False):
+        self.size = size
+        self.phandle = phandle
+
     @staticmethod
     def constructor(loader, node):
-        return phandle_int(loader.construct_yaml_int(node))
+        return sized_int(loader.construct_yaml_int(node), phandle=True)
+
 
 rtyaml = ruamel.yaml.YAML(typ='rt')
 rtyaml.allow_duplicate_keys = False
-rtyaml.preserve_quotes=True
+rtyaml.preserve_quotes = True
 rtyaml.Constructor.add_constructor(u'!u8', tagged_list.constructor)
 rtyaml.Constructor.add_constructor(u'!u16', tagged_list.constructor)
 rtyaml.Constructor.add_constructor(u'!u32', tagged_list.constructor)
 rtyaml.Constructor.add_constructor(u'!u64', tagged_list.constructor)
-rtyaml.Constructor.add_constructor(u'!phandle', phandle_int.constructor)
+rtyaml.Constructor.add_constructor(u'!phandle', sized_int.constructor)
 
 yaml = ruamel.yaml.YAML(typ='safe')
 yaml.allow_duplicate_keys = False
@@ -60,13 +62,15 @@ yaml.Constructor.add_constructor(u'!u8', tagged_list.constructor)
 yaml.Constructor.add_constructor(u'!u16', tagged_list.constructor)
 yaml.Constructor.add_constructor(u'!u32', tagged_list.constructor)
 yaml.Constructor.add_constructor(u'!u64', tagged_list.constructor)
-yaml.Constructor.add_constructor(u'!phandle', phandle_int.constructor)
+yaml.Constructor.add_constructor(u'!phandle', sized_int.constructor)
+
 
 def path_to_obj(tree, path):
     for pc in path:
         tree = tree[pc]
     return tree
 
+
 def get_line_col(tree, path, obj=None):
     if isinstance(obj, ruamel.yaml.comments.CommentedBase):
         return obj.lc.line, obj.lc.col
@@ -82,12 +86,15 @@ def get_line_col(tree, path, obj=None):
         return obj.lc.key(path[-1])
     return -1, -1
 
+
 schema_user_paths = []
 
+
 def add_schema_path(path):
     if os.path.isdir(path):
         schema_user_paths.append(os.path.abspath(path))
 
+
 def check_id_path(filename, id):
     id = id.replace('http://devicetree.org/schemas/', '')
     id = id.replace('#', '')
@@ -101,7 +108,11 @@ def check_id_path(filename, id):
     base = base.replace(os.path.abspath('schemas/') + '/', '')
 
     if not id == base:
-        print(filename + ": $id: relative path/filename doesn't match actual path or filename\n\texpected: http://devicetree.org/schemas/" + base + '#' , file=sys.stderr)
+        print(filename +
+              ": $id: relative path/filename doesn't match actual path or filename\n\texpected: http://devicetree.org/schemas/" +
+              base + '#',
+              file=sys.stderr)
+
 
 def do_load(filename):
     with open(filename, 'r', encoding='utf-8') as f:
@@ -110,6 +121,7 @@ def do_load(filename):
 
         return yaml.load(f.read())
 
+
 def load_schema(schema):
     for path in schema_user_paths:
         if schema.startswith('schemas/'):
@@ -124,8 +136,9 @@ def load_schema(schema):
 
     return do_load(os.path.join(schema_basedir, schema))
 
+
 def _value_is_type(subschema, key, type):
-    if not key in subschema:
+    if key not in subschema:
         return False
 
     if isinstance(subschema[key], list):
@@ -135,6 +148,7 @@ def _value_is_type(subschema, key, type):
 
     return isinstance(val, type)
 
+
 def _is_int_schema(subschema):
     for match in ['const', 'enum', 'minimum', 'maximum']:
         if _value_is_type(subschema, match, int):
@@ -142,6 +156,7 @@ def _is_int_schema(subschema):
 
     return False
 
+
 def _is_string_schema(subschema):
     for match in ['const', 'enum', 'pattern']:
         if _value_is_type(subschema, match, str):
@@ -149,18 +164,21 @@ def _is_string_schema(subschema):
 
     return False
 
+
 def _extract_single_schemas(subschema):
-    return { k: subschema.pop(k) for k in ('const', 'enum', 'pattern', 'minimum', 'maximum') if k in subschema }
+    return {k: subschema.pop(k) for k in ('const', 'enum', 'pattern', 'minimum', 'maximum') if k in subschema}
+
 
 def _fixup_string_to_array(propname, subschema):
     # nothing to do if we don't have a set of string schema
     if not _is_string_schema(subschema):
         return
 
-    subschema['items'] = [ _extract_single_schemas(subschema) ]
+    subschema['items'] = [_extract_single_schemas(subschema)]
+
 
 def _is_matrix_schema(subschema):
-    if not 'items' in subschema:
+    if 'items' not in subschema:
         return False
 
     if isinstance(subschema['items'], list):
@@ -172,6 +190,11 @@ def _is_matrix_schema(subschema):
 
     return False
 
+
+int_array_re = re.compile('int(8|16|32|64)-array')
+unit_types_re = re.compile('-(bits|percent|mhz|hz|sec|ms|us|ns|ps|mm|microamp|microamp-hours|ohms|micro-ohms|microwatt-hours|microvolt|picofarads|celsius|millicelsius|kpascal)$')
+
+
 def is_int_array_schema(propname, subschema):
     if 'allOf' in subschema:
         # Find 'items'. It may be under the 'allOf' or at the same level
@@ -180,13 +203,16 @@ def is_int_array_schema(propname, subschema):
                 subschema = item
                 continue
             if '$ref' in item:
-                return re.match('.*uint(8|16|32)-array', item['$ref'])
-    elif re.match('.*-(bits|percent|mhz|hz|sec|ms|us|ns|ps|mm|microamp|microamp-hours|ohms|micro-ohms|microwatt-hours|microvolt|picofarads|celsius|millicelsius|kpascal)$', propname):
+                return int_array_re.search(item['$ref'])
+    if '$ref' in subschema:
+        return int_array_re.search(subschema['$ref'])
+    elif unit_types_re.search(propname):
         return True
 
     return 'items' in subschema and \
-        ((isinstance(subschema['items'],list) and _is_int_schema(subschema['items'][0])) or \
-        (isinstance(subschema['items'],dict) and _is_int_schema(subschema['items'])))
+        ((isinstance(subschema['items'], list) and _is_int_schema(subschema['items'][0])) or
+         (isinstance(subschema['items'], dict) and _is_int_schema(subschema['items'])))
+
 
 # Fixup an int array that only defines the number of items.
 # In this case, we allow either form [[ 0, 1, 2]] or [[0], [1], [2]]
@@ -201,7 +227,7 @@ def _fixup_int_array_min_max_to_matrix(propname, subschema):
                 subschema = item
                 break
 
-    if 'items' in subschema and isinstance(subschema['items'],list):
+    if 'items' in subschema and isinstance(subschema['items'], list):
         return
 
     if _is_matrix_schema(subschema):
@@ -217,8 +243,8 @@ def _fixup_int_array_min_max_to_matrix(propname, subschema):
         tmpsch['maxItems'] = subschema.pop('maxItems')
 
     if tmpsch:
-        subschema['oneOf'] = [ copy.deepcopy(tmpsch), {'items': [ copy.deepcopy(tmpsch) ]} ]
-        subschema['oneOf'][0].update({'items': { 'maxItems': 1 }})
+        subschema['oneOf'] = [copy.deepcopy(tmpsch), {'items': [copy.deepcopy(tmpsch)]}]
+        subschema['oneOf'][0].update({'items': {'maxItems': 1}})
 
         # if minItems can be 1, then both oneOf clauses can be true so increment
         # minItems in one clause to prevent that.
@@ -228,8 +254,28 @@ def _fixup_int_array_min_max_to_matrix(propname, subschema):
         # Since we added an 'oneOf' the tree walking code won't find it and we need to do fixups
         _fixup_items_size(subschema['oneOf'])
 
+
+def _fixup_remove_empty_items(subschema):
+    if 'items' not in subschema:
+        return
+    elif isinstance(subschema['items'], dict):
+        _fixup_remove_empty_items(subschema['items'])
+        return
+
+    for item in subschema['items']:
+        item.pop('description', None)
+        _fixup_remove_empty_items(item)
+        if item != {}:
+            break
+    else:
+        subschema.setdefault('type', 'array')
+        subschema.setdefault('maxItems', len(subschema['items']))
+        subschema.setdefault('minItems', len(subschema['items']))
+        del subschema['items']
+
+
 def _fixup_int_array_items_to_matrix(propname, subschema):
-    itemkeys = ('items','minItems','maxItems', 'uniqueItems', 'default')
+    itemkeys = ('items', 'minItems', 'maxItems', 'uniqueItems', 'default')
     if not is_int_array_schema(propname, subschema):
         return
 
@@ -240,20 +286,22 @@ def _fixup_int_array_items_to_matrix(propname, subschema):
                 subschema = item
                 break
 
-    if not 'items' in subschema or _is_matrix_schema(subschema):
+    if 'items' not in subschema or _is_matrix_schema(subschema):
         return
 
-    if isinstance(subschema['items'],dict):
+    if isinstance(subschema['items'], dict):
         subschema['items'] = {k: subschema.pop(k) for k in itemkeys if k in subschema}
 
-    if isinstance(subschema['items'],list):
-        subschema['items'] = [ {k: subschema.pop(k) for k in itemkeys if k in subschema} ]
+    if isinstance(subschema['items'], list):
+        subschema['items'] = [{k: subschema.pop(k) for k in itemkeys if k in subschema}]
+
 
 def _fixup_scalar_to_array(propname, subschema):
     if not _is_int_schema(subschema):
         return
 
-    subschema['items'] = [ {'items': [ _extract_single_schemas(subschema) ] } ]
+    subschema['items'] = [{'items': [_extract_single_schemas(subschema)]}]
+
 
 def _fixup_items_size(schema):
     # Make items list fixed size-spec
@@ -267,38 +315,75 @@ def _fixup_items_size(schema):
 
             if isinstance(schema['items'], list):
                 c = len(schema['items'])
-                if not 'minItems' in schema:
+                if 'minItems' not in schema:
                     schema['minItems'] = c
-                if not 'maxItems' in schema:
+                if 'maxItems' not in schema:
                     schema['maxItems'] = c
 
-                if not 'additionalItems' in schema:
-                    schema['additionalItems'] = False
-
             _fixup_items_size(schema['items'])
 
-        elif 'maxItems' in schema and not 'minItems' in schema:
+        elif 'maxItems' in schema and 'minItems' not in schema:
             schema['minItems'] = schema['maxItems']
-        elif 'minItems' in schema and not 'maxItems' in schema:
+        elif 'minItems' in schema and 'maxItems' not in schema:
             schema['maxItems'] = schema['minItems']
 
+
+def fixup_schema_to_201909(schema):
+    if not isinstance(schema, dict):
+        return
+
+    # dependencies is now split into dependentRequired and dependentSchema
+    try:
+        val = schema.pop('dependencies')
+        for k, v in val.items():
+            if isinstance(v, list):
+                schema.setdefault('dependentRequired', {})
+                schema['dependentRequired'][k] = v
+            else:
+                schema.setdefault('dependentSchemas', {})
+                schema['dependentSchemas'][k] = v
+    except:
+        pass
+
+
+def fixup_schema_to_202012(schema):
+    if not isinstance(schema, dict):
+        return
+
+    fixup_schema_to_201909(schema)
+
+    try:
+        if isinstance(schema['items'], list):
+            schema['prefixItems'] = schema.pop('items')
+            for i in schema['prefixItems']:
+                fixup_schema_to_202012(i)
+        if isinstance(schema['items'], dict):
+            fixup_schema_to_202012(schema['items'])
+    except:
+        pass
+
+    try:
+        val = schema.pop('additionalItems')
+        schema['unevaluatedItems'] = val
+    except:
+        pass
+
+
 def fixup_vals(propname, schema):
     # Now we should be a the schema level to do actual fixups
-#    print(schema)
+    #print(schema)
 
     schema.pop('description', None)
 
-    # This can be removed once draft 2019.09 is supported
-    if '$ref' in schema and (len(schema) > 1):
-        schema['allOf'] = [ {'$ref': schema['$ref']} ]
-        schema.pop('$ref')
-
+    _fixup_remove_empty_items(schema)
     _fixup_int_array_min_max_to_matrix(propname, schema)
     _fixup_int_array_items_to_matrix(propname, schema)
     _fixup_string_to_array(propname, schema)
     _fixup_scalar_to_array(propname, schema)
     _fixup_items_size(schema)
-#    print(schema)
+
+    fixup_schema_to_201909(schema)
+
 
 def walk_properties(propname, schema):
     if not isinstance(schema, dict):
@@ -311,8 +396,12 @@ def walk_properties(propname, schema):
             for l in schema[cond]:
                 walk_properties(propname, l)
 
+    if 'then' in schema.keys():
+        walk_properties(propname, schema['then'])
+
     fixup_vals(propname, schema)
 
+
 def fixup_schema(schema):
     # Remove parts not necessary for validation
     schema.pop('examples', None)
@@ -322,6 +411,7 @@ def fixup_schema(schema):
     add_select_schema(schema)
     fixup_sub_schema(schema, True)
 
+
 def fixup_sub_schema(schema, is_prop):
     if not isinstance(schema, dict):
         return
@@ -331,7 +421,7 @@ def fixup_sub_schema(schema, is_prop):
     if is_prop:
         fixup_node_props(schema)
 
-    for k,v in schema.items():
+    for k, v in schema.items():
         if k in ['select', 'if', 'then', 'else', 'additionalProperties', 'not']:
             fixup_sub_schema(v, False)
 
@@ -339,7 +429,7 @@ def fixup_sub_schema(schema, is_prop):
             for subschema in v:
                 fixup_sub_schema(subschema, True)
 
-        if not k in ['dependencies', 'properties', 'patternProperties', '$defs']:
+        if k not in ['dependentRequired', 'dependentSchemas', 'dependencies', 'properties', 'patternProperties', '$defs']:
             continue
 
         for prop in v:
@@ -347,6 +437,9 @@ def fixup_sub_schema(schema, is_prop):
             # Recurse to check for {properties,patternProperties} in each prop
             fixup_sub_schema(v[prop], True)
 
+    fixup_schema_to_201909(schema)
+
+
 def fixup_node_props(schema):
     if not {'properties', 'patternProperties'} & schema.keys():
         return
@@ -355,11 +448,9 @@ def fixup_node_props(schema):
         return
 
     schema.setdefault('properties', dict())
-    schema['properties']['phandle'] = True
-    schema['properties']['status'] = True
-
-    if not '$nodename' in schema['properties']:
-        schema['properties']['$nodename'] = True
+    schema['properties'].setdefault('phandle', True)
+    schema['properties'].setdefault('status', True)
+    schema['properties'].setdefault('$nodename', True)
 
     keys = list()
     if 'properties' in schema:
@@ -376,11 +467,12 @@ def fixup_node_props(schema):
         schema.setdefault('patternProperties', dict())
         schema['patternProperties']['pinctrl-[0-9]+'] = True
 
-    if "clocks" in keys and not "assigned-clocks" in keys:
+    if "clocks" in keys and "assigned-clocks" not in keys:
         schema['properties']['assigned-clocks'] = True
         schema['properties']['assigned-clock-rates'] = True
         schema['properties']['assigned-clock-parents'] = True
 
+
 def extract_node_compatibles(schema):
     if not isinstance(schema, dict):
         return set()
@@ -399,6 +491,7 @@ def extract_node_compatibles(schema):
 
     return compatible_list
 
+
 def extract_compatibles(schema):
     if not isinstance(schema, dict):
         return set()
@@ -409,6 +502,7 @@ def extract_compatibles(schema):
 
     return compatible_list
 
+
 def item_generator(json_input, lookup_key):
     if isinstance(json_input, dict):
         for k, v in json_input.items():
@@ -422,6 +516,7 @@ def item_generator(json_input, lookup_key):
             for item_val in item_generator(item, lookup_key):
                 yield item_val
 
+
 # Convert to standard types from ruamel's CommentedMap/Seq
 def convert_to_dict(schema):
     if isinstance(schema, dict):
@@ -437,6 +532,7 @@ def convert_to_dict(schema):
 
     return result
 
+
 def add_select_schema(schema):
     '''Get a schema to be used in select tests.
 
@@ -448,7 +544,7 @@ def add_select_schema(schema):
     if "select" in schema:
         return
 
-    if not 'properties' in schema:
+    if 'properties' not in schema:
         schema['select'] = False
         return
 
@@ -472,28 +568,30 @@ def add_select_schema(schema):
 
                 return
 
-    if '$nodename' in schema['properties'] and schema['properties']['$nodename'] != True:
+    if '$nodename' in schema['properties'] and schema['properties']['$nodename'] is not True:
         schema['select'] = {
             'required': ['$nodename'],
-            'properties': {'$nodename': convert_to_dict(schema['properties']['$nodename']) }}
+            'properties': {'$nodename': convert_to_dict(schema['properties']['$nodename'])}}
 
         return
 
     schema['select'] = False
 
+
 def fixup_interrupts(schema):
     # Supporting 'interrupts' implies 'interrupts-extended' is also supported.
-    if not 'properties' in schema:
+    if 'properties' not in schema:
         return
 
     # Any node with 'interrupts' can have 'interrupt-parent'
-    if schema['properties'].keys() & {'interrupts', 'interrupt-controller'}:
+    if schema['properties'].keys() & {'interrupts', 'interrupt-controller'} and \
+       'interrupt-parent' not in schema['properties']:
         schema['properties']['interrupt-parent'] = True
 
-    if not 'interrupts' in schema['properties']:
+    if 'interrupts' not in schema['properties'] or 'interrupts-extended' in schema['properties']:
         return
 
-    schema['properties']['interrupts-extended'] = copy.deepcopy(schema['properties']['interrupts']);
+    schema['properties']['interrupts-extended'] = copy.deepcopy(schema['properties']['interrupts'])
 
     if not ('required' in schema and 'interrupts' in schema['required']):
         return
@@ -501,15 +599,16 @@ def fixup_interrupts(schema):
     # Currently no better way to express either 'interrupts' or 'interrupts-extended'
     # is required. If this fails validation, the error reporting is the whole
     # schema file fails validation
-    reqlist = [ {'required': ['interrupts']}, {'required': ['interrupts-extended']} ]
+    reqlist = [{'required': ['interrupts']}, {'required': ['interrupts-extended']}]
     if 'oneOf' in schema:
-        if not 'allOf' in schema:
+        if 'allOf' not in schema:
             schema['allOf'] = []
-        schema['allOf'].append({ 'oneOf': reqlist })
+        schema['allOf'].append({'oneOf': reqlist})
     else:
         schema['oneOf'] = reqlist
     schema['required'].remove('interrupts')
 
+
 def make_compatible_schema(schemas):
     compat_sch = [{'enum': []}]
     compatible_list = set()
@@ -524,7 +623,7 @@ def make_compatible_schema(schemas):
         if prog.match(c):
             # Exclude the generic pattern
             if c != '^[a-zA-Z][a-zA-Z0-9,+\-._]+$':
-                compat_sch += [{'pattern': c }]
+                compat_sch += [{'pattern': c}]
         else:
             compat_sch[0]['enum'].append(c)
 
@@ -542,10 +641,11 @@ def make_compatible_schema(schemas):
         }
     }]
 
+
 def process_schema(filename):
     try:
         schema = load_schema(filename)
-    except ruamel.yaml.error.YAMLError as exc:
+    except:
         print(filename + ": ignoring, error parsing file", file=sys.stderr)
         return
 
@@ -553,17 +653,20 @@ def process_schema(filename):
     try:
         DTValidator.check_schema(schema)
     except jsonschema.SchemaError as exc:
-        print(filename + ": ignoring, error in schema: " + ': '.join(str(x) for x in exc.path), file=sys.stderr)
+        print(filename + ": ignoring, error in schema: " + ': '.join(str(x) for x in exc.path),
+              file=sys.stderr)
         #print(exc.message)
         return
 
-    if not 'select' in schema:
+    if 'select' not in schema:
+        print(filename + ": warning: no 'select' found in schema found", file=sys.stderr)
         return
 
     schema["type"] = "object"
     schema["$filename"] = filename
     return schema
 
+
 def process_schemas(schema_paths, core_schema=True):
     ids = []
     schemas = []
@@ -572,13 +675,12 @@ def process_schemas(schema_paths, core_schema=True):
         if not os.path.isfile(filename):
             continue
         sch = process_schema(os.path.abspath(filename))
-        if sch:
-            schemas.append(sch)
-            if ids.count(sch['$id']):
-                print(os.path.abspath(filename) + ": duplicate '$id' value '" + sch['$id'] + "'", file=sys.stderr)
-            ids.append(sch['$id'])
-        else:
-            print("warning: no schema found in file: %s" % filename, file=sys.stderr)
+        if not sch:
+            continue
+        schemas.append(sch)
+        if ids.count(sch['$id']):
+            print(os.path.abspath(filename) + ": duplicate '$id' value '" + sch['$id'] + "'", file=sys.stderr)
+        ids.append(sch['$id'])
 
     if core_schema:
         schema_paths.append(os.path.join(schema_basedir, 'schemas/'))
@@ -604,6 +706,7 @@ def process_schemas(schema_paths, core_schema=True):
 
     return schemas
 
+
 def load(filename, line_number=False):
     with open(filename, 'r', encoding='utf-8') as f:
         if line_number:
@@ -611,12 +714,15 @@ def load(filename, line_number=False):
         else:
             return yaml.load(f.read())
 
+
 schema_cache = []
 
+
 def set_schema(schemas):
     global schema_cache
     schema_cache = schemas
 
+
 def http_handler(uri):
     global schema_cache
     '''Custom handler for http://devicetre.org YAML references'''
@@ -629,29 +735,36 @@ def http_handler(uri):
                 return load_schema(uri.replace(schema_base_url, ''))
             return process_schema(uri.replace(schema_base_url, ''))
 
+        from urllib.request import urlopen
+
         return yaml.load(urlopen(uri).read().decode('utf-8'))
     except FileNotFoundError as e:
         print('Unknown file referenced:', e, file=sys.stderr)
         exit(-1)
 
+
 handlers = {"http": http_handler}
 
+
 def typeSize(validator, typeSize, instance, schema):
-    if (isinstance(instance[0], tagged_list)):
-        if typeSize != instance[0].type_size:
-            yield jsonschema.ValidationError("size is %r, expected %r" % (instance[0].type_size, typeSize))
-    elif isinstance(instance[0], list) and isinstance(instance[0][0], int) and \
-        typeSize == 32:
-        # 32-bit sizes aren't explicitly tagged
+    if not isinstance(instance[0], list):
         return
+    if isinstance(instance[0][0], sized_int):
+        size = instance[0][0].size
     else:
-        yield jsonschema.ValidationError("missing size tag in %r" % instance)
+        size = 32
+
+    if typeSize != size:
+        yield jsonschema.ValidationError("size is %r, expected %r" % (size, typeSize))
+
 
 def phandle(validator, phandle, instance, schema):
-    if not isinstance(instance, phandle_int):
+    if not isinstance(instance, sized_int) or not instance.phandle:
         yield jsonschema.ValidationError("missing phandle tag in %r" % instance)
 
-DTVal = jsonschema.validators.extend(jsonschema.Draft7Validator, {'typeSize': typeSize, 'phandle': phandle})
+
+DTVal = jsonschema.validators.extend(jsonschema.Draft201909Validator, {'typeSize': typeSize, 'phandle': phandle})
+
 
 class DTValidator(DTVal):
     '''Custom Validator for Devicetree Schemas
@@ -756,12 +869,11 @@ class DTValidator(DTVal):
 
         check_id_path(filename, schema['$id'])
 
-
     @classmethod
     def _check_str(self, err_msg, schema, key, v):
         if not (isinstance(v, ruamel.yaml.scalarstring.SingleQuotedScalarString) or
-           isinstance(v, ruamel.yaml.scalarstring.DoubleQuotedScalarString)):
-           return
+                isinstance(v, ruamel.yaml.scalarstring.DoubleQuotedScalarString)):
+            return
 
         # Only checking const and list values
         if key and key != 'const':
@@ -788,7 +900,7 @@ class DTValidator(DTVal):
     @classmethod
     def check_quotes(self, err_msg, schema):
         if isinstance(schema, dict):
-            for k,v in schema.items():
+            for k, v in schema.items():
                 self._check_str(err_msg, schema, k, v)
                 self.check_quotes(err_msg, v)
 
@@ -797,11 +909,12 @@ class DTValidator(DTVal):
                 self._check_str(err_msg, schema, None, s)
                 self.check_quotes(err_msg, s)
 
+
 def format_error(filename, error, prefix="", nodename=None, verbose=False):
     src = prefix + os.path.abspath(filename) + ':'
 
-    if error.linecol[0] >= 0 :
-        src = src + '%i:%i: '%(error.linecol[0]+1, error.linecol[1]+1)
+    if error.linecol[0] >= 0:
+        src = src + '%i:%i: ' % (error.linecol[0]+1, error.linecol[1]+1)
     else:
         src += ' '
 
@@ -823,7 +936,7 @@ def format_error(filename, error, prefix="", nodename=None, verbose=False):
         for suberror in sorted(error.context, key=lambda e: e.path):
             if suberror.context:
                 msg += '\n' + format_error(filename, suberror, prefix=prefix+"\t", nodename=nodename, verbose=verbose)
-            elif not suberror.message in msg:
+            elif suberror.message not in msg:
                 msg += '\n' + prefix + '\t' + suberror.message
                 if suberror.note and suberror.note != error.note:
                     msg += '\n\t\t' + prefix + 'hint: ' + suberror.note
